This is unreleased documentation for the main (development) branch of crypto-glue.

Profile

Trait Profile 

pub trait Profile:
    PartialEq
    + Debug
    + Eq
    + Clone {
    // Provided method
    fn check_serial_number(serial: &SerialNumber<Self>) -> Result<()> { ... }
}
Profile allows the consumer of this crate to customize the behavior when parsing certificates. By default, parsing will be made in a rfc5280-compliant manner.

Provided Methods

fn check_serial_number(serial: &SerialNumber<Self>) -> Result<()>

Checks to run when parsing serial numbers

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl Profile for Raw

Available on crate feature hazmat only.
Source

impl Profile for Rfc5280